@@ -6,14 +6,15 @@ import sys
 from rbtools.clients import PatchResult, SCMClient, RepositoryInfo
 from rbtools.clients.errors import (AmendError, MergeError, PushError,
                                     InvalidRevisionSpecError,
-                                    TooManyRevisionsError)
+                                    TooManyRevisionsError,
+                                    SCMError)
 from rbtools.clients.perforce import PerforceClient
 from rbtools.clients.svn import SVNClient, SVNRepositoryInfo
 from rbtools.utils.checks import check_install, is_valid_version
 from rbtools.utils.console import edit_text
 from rbtools.utils.diffs import (normalize_patterns,
                                  remove_filenames_matching_patterns)
-from rbtools.utils.process import die, execute
+from rbtools.utils.process import execute
 
 
 class GitClient(SCMClient):
@@ -115,12 +116,14 @@ class GitClient(SCMClient):
                 result['base'] = merge_base
 
             # Since the user asked us to operate on HEAD, warn them about a
-            # dirty working directory
-            if self.has_pending_changes():
+            # dirty working directory.
+            if (self.has_pending_changes() and
+                not self.config.get('SUPPRESS_CLIENT_WARNINGS', False)):
                 logging.warning('Your working directory is not clean. Any '
                                 'changes which have not been committed '
                                 'to a branch will not be included in your '
                                 'review request.')
+
         elif n_revs == 1 or n_revs == 2:
             # Let `git rev-parse` sort things out.
             parsed = self._rev_parse(revisions)
@@ -294,8 +297,8 @@ class GitClient(SCMClient):
                                           int(version_parts.group(2)),
                                           int(version_parts.group(3))),
                                          (1, 5, 4))):
-                    die("Your installation of git-svn must be upgraded to "
-                        "version 1.5.4 or later")
+                    raise SCMError('Your installation of git-svn must be '
+                                   'upgraded to version 1.5.4 or later.')
 
         # Okay, maybe Perforce (git-p4).
         git_p4_ref = os.path.join(git_dir, 'refs', 'remotes', 'p4', 'master')
@@ -719,7 +722,7 @@ class GitClient(SCMClient):
         have been staged in the index, otherwise returns False.
         """
         status = execute(['git', 'status', '--porcelain',
-                          '--untracked-files=no'])
+                          '--untracked-files=no', '--ignore-submodules=dirty'])
         return status != ''
 
     def amend_commit_description(self, message, revisions):
