@@ -20,10 +20,11 @@ from rbtools.clients import scan_usable_client
 from rbtools.clients.errors import OptionsCheckError
 from rbtools.utils.filesystem import (cleanup_tempfiles, get_home_path,
                                       load_config)
-from rbtools.utils.process import die
 
 
-RB_MAIN = 'rbt'
+# NOTE: This needs to be a byte string, since it's going to go in argv,
+#       which are all expected to be byte strings.
+RB_MAIN = b'rbt'
 
 
 class CommandExit(Exception):
@@ -655,7 +656,8 @@ class Command(object):
             sys.exit(1)
 
         self.init_logging()
-        logging.debug('Command line: %s', subprocess.list2cmdline(argv))
+        logging.debug('Command line: %s',
+                      subprocess.list2cmdline(argv).decode('utf8'))
 
         try:
             exit_code = self.main(*args) or 0
@@ -692,8 +694,7 @@ class Command(object):
         try:
             tool.check_options()
         except OptionsCheckError as e:
-            sys.stderr.write('%s\n' % e)
-            sys.exit(1)
+            raise CommandError('%s\n' % e)
 
         return repository_info, tool
 
@@ -727,9 +728,8 @@ class Command(object):
             server_url = None
 
         if not server_url:
-            print('Unable to find a Review Board server for this source code '
-                  'tree.')
-            sys.exit(1)
+            raise CommandError('Unable to find a Review Board server for this '
+                               'source code tree.')
 
         return server_url
 
@@ -743,8 +743,8 @@ class Command(object):
         """
         if username is None or password is None:
             if getattr(self.options, 'diff_filename', None) == '-':
-                die('HTTP authentication is required, but cannot be '
-                    'used with --diff-filename=-')
+                raise CommandError('HTTP authentication is required, but '
+                                   'cannot be used with --diff-filename=-')
 
             # Interactive prompts don't work correctly when input doesn't come
             # from a terminal. This could seem to be a rare case not worth
@@ -786,8 +786,9 @@ class Command(object):
         or application. The user will be prompted for this token.
         """
         if getattr(self.options, 'diff_filename', None) == '-':
-            die('A two-factor authentication token is required, but cannot '
-                'be used with --diff-filename=-')
+            raise CommandError('A two-factor authentication token is '
+                               'required, but cannot be used with '
+                               '--diff-filename=-')
 
         print()
         print('Please enter your two-factor authentication token for Review '
